@@ -52,13 +52,13 @@ async def get_from_rq(request_url, timeout=0):
 
 
 async def request_json_from_rq(api, qid, timeout=0):
-    api_url = urljoin(api, "request/recv/?q=%s" % qid)
+    api_url = urljoin(api, "request/pop/?q=%s" % qid)
     status, ret = await get_from_rq(api_url, timeout=timeout)
     return status, ret, api_url
 
 
 async def queues_json_from_rq(api, k=10, timeout=0):
-    api_url = urljoin(api, "rq/queues/?k=%d" % k)
+    api_url = urljoin(api, "queues/?k=%d" % k)
     status, ret = await get_from_rq(api_url, timeout=timeout)
     return status, ret, api_url
 
